# 绝绝子网盘搜索

一个简洁的网盘资源搜索工具，支持多平台资源搜索，提供现代化的用户界面和流畅的搜索体验。

## 功能特点

- 🔍 快速搜索：支持多平台网盘资源搜索
- 🎨 现代化界面：采用 Material Design 设计风格
- 🌙 深色模式：支持自动切换深色/浅色主题
- 📱 响应式设计：完美适配各种设备尺寸
- ⚡ 性能优化：快速加载，流畅体验

## 技术栈

- Vue 3 - 前端框架
- Vite - 构建工具
- TailwindCSS - 样式框架
- Axios - HTTP 客户端
- Vue Router - 路由管理
- Pinia - 状态管理

## 开发指南

### 环境要求

- Node.js >= 16.0.0
- npm >= 7.0.0

### 安装依赖

```bash
npm install
```

### 开发环境

```bash
npm run dev
```

### 构建生产版本

```bash
npm run build
```

## 部署说明

### 1. 构建项目

```bash
npm run build
```

构建完成后，文件将生成在 `dist` 目录中。

### 2. 配置 Nginx

项目提供了一个 `nginx.conf.template` 配置模板文件，使用时需要：

1. 复制 `nginx.conf.template` 文件并重命名为 `nginx.conf`
2. 替换文件中的以下占位符：
   - `[你的域名]`: 网站域名，如 `pan.example.com`
   - `[你的网站根目录]`: 网站文件存放目录，如 `/www/wwwroot/pan.example.com`
   - `[日志目录]`: 日志文件存放目录，如 `/www/wwwlogs/pan.example.com`
   - `[目标API地址]`: API 服务器地址，如 `https://api.example.com/`
   - `[允许的域名]`: 允许跨域访问的域名，如 `https://pan.example.com`

示例配置：

```nginx
server {
    listen 80;
    server_name pan.example.com;
    root /www/wwwroot/pan.example.com;
    index index.html;

    access_log /www/wwwlogs/pan.example.com/access.log;
    error_log /www/wwwlogs/pan.example.com/error.log;

    location /api/ {
        proxy_pass https://api.example.com/;
        proxy_set_header Host $host;
        proxy_set_header X-Real-IP $remote_addr;
        
        add_header 'Access-Control-Allow-Origin' 'https://pan.example.com' always;
        # ... 其他配置 ...
    }
    
    # ... 其他配置 ...
}
```

### 3. 上传文件

将 `dist` 目录中的所有文件上传到服务器的网站根目录。

### 4. 配置域名

确保域名已正确解析到服务器IP，并在服务器上配置好SSL证书（如果需要）。

## 注意事项

- 在部署到生产环境之前，请确保所有占位符都已正确替换
- 建议启用 HTTPS 以提升安全性
- 定期备份网站数据和日志文件
- 监控服务器资源使用情况，及时优化配置

## 许可证

MIT License 